{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-rating:pyfb_rating_providerregionrate_list' %}">ProviderRegionRate Listing</a></p>
<table class="table">
</table>
<a class="btn btn-primary" href="{{object.get_update_url}}">Edit ProviderRegionRate</a>

{% endblock %}
