# Generated by Django 2.1.4 on 2018-12-07 15:17

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_rating', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='customerratecard',
            name='callerid_list',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='pyfb_rating.CallerNumList'),
        ),
        migrations.AlterField(
            model_name='providerratecard',
            name='callerid_list',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='pyfb_rating.CallerNumList'),
        ),
        migrations.AlterField(
            model_name='providerratecard',
            name='provider_prefix',
            field=models.CharField(blank=True, default='', max_length=10, verbose_name='tech prefix'),
        ),
    ]
