{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-rating:pyfb_rating_providerratecard_list' %}">ProviderRatecard Listing</a></p>
<table class="table">
<tr>
<td>ID</td><td>Link</td>
    <td>name</td>
    <td>slug</td>
    <td>rc_type</td>
    <td>provider_prefix</td>
    <td>estimated_quality</td>
    <td>status</td>
    <td>status_changed</td>
    <td>created</td>
    <td>modified</td>
</tr>
{% for object in object_list %}
<tr>
    <td>{{object.pk}}</td>
    <td><a href="{{object.get_absolute_url}}">{{object}}</a></td>
    <td>{{ object.name }}</td>
    <td>{{ object.slug }}</td>
    <td>{{ object.rc_type }}</td>
    <td>{{ object.provider_prefix }}</td>
    <td>{{ object.estimated_quality }}</td>
    <td>{{ object.status }}</td>
    <td>{{ object.status_changed }}</td>
    <td>{{ object.created }}</td>
    <td>{{ object.modified }}</td>
</tr>
{% endfor %}
</table><a class="btn btn-primary" href="{% url 'pyfb-rating:pyfb_rating_providerratecard_create' %}">Create new ProviderRatecard</a>
{% endblock %}
