{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-rating:pyfb_rating_customerratecard_list' %}">CustomerRatecard Listing</a></p>
<table class="table">
<tr><td>slug</td><td>{{ object.slug }}</td></tr>
<tr><td>rc_type</td><td>{{ object.rc_type }}</td></tr>
<tr><td>name</td><td>{{ object.name }}</td></tr>
<tr><td>status</td><td>{{ object.status }}</td></tr>
<tr><td>status_changed</td><td>{{ object.status_changed }}</td></tr>
<tr><td>created</td><td>{{ object.created }}</td></tr>
<tr><td>modified</td><td>{{ object.modified }}</td></tr>
</table>
<a class="btn btn-primary" href="{{object.get_update_url}}">Edit CustomerRatecard</a>

{% endblock %}
