{% extends "base.html" %}
{% load static %}
{% load i18n %}
{% block content %}
<p><a class="btn btn-default" href="{% url 'pyfb-rating:pyfb_rating_callernumlist_list' %}">CallerNumList Listing</a></p>
<table class="table">
<tr><td>name</td><td>{{ object.name }}</td></tr>
<tr><td>slug</td><td>{{ object.slug }}</td></tr>
<tr><td>callerid_filter</td><td>{{ object.callerid_filter }}</td></tr>
</table>
<a class="btn btn-primary" href="{{object.get_update_url}}">Edit CallerNumList</a>

{% endblock %}
